#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 trifecta
version:              2.1.4
visibility:           public
id:                   trifecta-2.1.4-KoT91AST2oAGwGiBWTWHDQ
key:                  trifecta-2.1.4-KoT91AST2oAGwGiBWTWHDQ
license:              BSD-3-Clause
copyright:            Copyright (C) 2010-2017 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            experimental
homepage:             http://github.com/ekmett/trifecta/
synopsis:
    A modern parser combinator library with convenient diagnostics

description:
    A modern parser combinator library with slicing and Clang-style colored diagnostics

    For example:

    <<https://i.imgur.com/ZyzUSSn.png>>

    <images/example.png (Local Copy)>

category:             Text, Parsing, Diagnostics, Pretty Printer, Logging
abi:                  3ba93f5f7a24b18b1790806923415eca
exposed:              True
exposed-modules:
    Text.Trifecta Text.Trifecta.Combinators Text.Trifecta.Delta
    Text.Trifecta.Highlight Text.Trifecta.Parser
    Text.Trifecta.Rendering Text.Trifecta.Result Text.Trifecta.Rope
    Text.Trifecta.Tutorial Text.Trifecta.Util.IntervalMap
    Text.Trifecta.Util.It

hidden-modules:
    Text.Trifecta.Util.Combinators Text.Trifecta.Util.Pretty

import-dirs:          /usr/lib/ghc-9.6.6/site-local/trifecta-2.1.4
library-dirs:         /usr/lib/ghc-9.6.6/site-local/trifecta-2.1.4
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/trifecta-2.1.4
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-trifecta
hs-libraries:         HStrifecta-2.1.4-KoT91AST2oAGwGiBWTWHDQ
depends:
    ansi-terminal-1.1-4r9UE8W85hy3ofo15nhM3F array-0.5.6.0
    base-4.18.2.1 blaze-builder-0.4.4.1-BgmztVD7kNkBjq1RMk7arZ
    blaze-html-0.9.2.0-BPrvNs5SEmQ5QlVsEK3wLT
    blaze-markup-0.8.3.0-8YrZMmZGB9X9ncqWE310lu bytestring-0.11.5.3
    charset-0.3.12-4UmFZTQxDsK9rHFPeKO9SL
    comonad-5.0.10-86EZ0y0Wl782nTUEGFZQS containers-0.6.7
    deepseq-1.4.8.1 fingertree-0.1.6.3-5EdGzVy2JWe6ekrJxjnukR
    ghc-prim-0.10.0 hashable-1.4.7.0-29C6HO1kEzxKGOntKCwjk4
    indexed-traversable-0.1.4-8j5HZpShpE5BqFup9Ojenr
    lens-5.3.4-6KV9HDCdZf8JKhnHS7R55U mtl-2.3.1
    parsers-0.12.12-DITnP6X1XI58dGVYmGX0ES
    prettyprinter-1.7.1-H2rJD2WExIbcRy2n74kLf
    prettyprinter-ansi-terminal-1.1.4-17QDQnvgM0PL8GivpLJq8k
    profunctors-5.6.3-ETGIlrten0M1x1aMjtopkb
    reducers-3.12.5-IKZcqrreAe95fct8bdjT9t transformers-0.6.1.0
    unordered-containers-0.2.20.1-Hsa9d2Ja6XgAATZt7ZTK9f
    utf8-string-1.0.2-GrV0vD7epd2Fw38ZtPT1hv

haddock-interfaces:   /usr/share/doc/haskell-trifecta/html/trifecta.haddock
haddock-html:         /usr/share/doc/haskell-trifecta/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

